@@ -44,7 +44,7 @@ class KERFUFFLE_EXPORT Plugin : public QObject
     /**
      * The priority of the plugin. The higher the better.
      */
-    Q_PROPERTY(unsigned int priority READ priority CONSTANT)
+    Q_PROPERTY(int priority READ priority CONSTANT)
 
     /**
      * Whether the plugin has been enabled in the settings.
@@ -74,10 +74,10 @@ class KERFUFFLE_EXPORT Plugin : public QObject
     Q_PROPERTY(KPluginMetaData metaData READ metaData MEMBER m_metaData CONSTANT)
 
 public:
-    explicit Plugin(QObject *parent = Q_NULLPTR, const KPluginMetaData& metaData = KPluginMetaData());
+    explicit Plugin(QObject *parent = nullptr, const KPluginMetaData& metaData = KPluginMetaData());
 
 
-    unsigned int priority() const;
+    int priority() const;
     bool isEnabled() const;
     void setEnabled(bool enabled);
     bool isReadWrite() const;
@@ -85,6 +85,12 @@ public:
     QStringList readWriteExecutables() const;
     KPluginMetaData metaData() const;
 
+    /**
+     * @return Whether the executables required for a functional plugin are installed.
+     * This is true if all the read-only executables are found in the path.
+     */
+    bool hasRequiredExecutables() const;
+
     /**
      * @return Whether the plugin is ready to be used.
      * This implies isEnabled(), while an enabled plugin may not be valid.
